pyflakes: Passive checker of Python programs
============================================

Description
-----------

passive checker of Python programs

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pyflakes/

